package com.doc.web.controller.system;

import com.doc.common.annotation.Log;
import com.doc.common.core.controller.BaseController;
import com.doc.common.core.domain.AjaxResult;
import com.doc.common.core.domain.entity.SysUserExpand;
import com.doc.common.core.page.TableDataInfo;
import com.doc.common.enums.BusinessType;
import com.doc.common.enums.EventLevel;
import com.doc.common.utils.poi.ExcelUtil;
import com.doc.system.service.ISysUserExpandService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 用户登录限制Controller
 *
 * @author wukai
 * @date 2023-10-11
 */
@Api(tags = "用户登录限制")
@RestController
@RequestMapping("/system/user/expand")
public class SysUserExpandController extends BaseController {
    @Resource
    private ISysUserExpandService sysUserExpandService;

    /**
     * 查询用户登录限制列表
     */
    @ApiOperation("查询用户登录限制列表")
    @PreAuthorize("@ss.hasPermi('system:expand:list')")
    @GetMapping("/list")
    public TableDataInfo list(SysUserExpand sysUserExpand) {
        startPage();
        List<SysUserExpand> list = sysUserExpandService.selectSysUserExpandList(sysUserExpand);
        return getDataTable(list);
    }

    /**
     * 导出用户登录限制列表
     */
    @ApiOperation("导出用户登录限制列表")
    @PreAuthorize("@ss.hasPermi('system:expand:export')")
    @Log(title = "用户登录限制", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysUserExpand sysUserExpand) {
        List<SysUserExpand> list = sysUserExpandService.selectSysUserExpandList(sysUserExpand);
        ExcelUtil<SysUserExpand> util = new ExcelUtil<SysUserExpand>(SysUserExpand.class);
        util.exportExcel(response, list, "用户登录限制数据");
    }

    /**
     * 获取用户登录限制详细信息
     */
    @ApiOperation("获取用户登录限制详细信息")
    @PreAuthorize("@ss.hasPermi('system:expand:query')")
    @GetMapping(value = "/{userId}")
    public AjaxResult getInfo(@PathVariable("userId") Long userId) {
        return success(sysUserExpandService.selectSysUserExpandByUserId(userId));
    }

    /**
     * 新增用户登录限制
     */
    @ApiOperation("新增用户登录限制")
    @PreAuthorize("@ss.hasPermi('system:expand:add')")
    @Log(title = "用户登录限制", businessType = BusinessType.INSERT,eventLevel = EventLevel.HIGH)
    @PostMapping
    public AjaxResult add(@RequestBody SysUserExpand sysUserExpand) {
        return toAjax(sysUserExpandService.insertSysUserExpand(sysUserExpand));
    }

    /**
     * 修改用户登录限制
     */
    @ApiOperation("修改用户登录限制")
    @PreAuthorize("@ss.hasPermi('system:expand:edit')")
    @Log(title = "用户登录限制", businessType = BusinessType.UPDATE,eventLevel = EventLevel.HIGH)
    @PutMapping
    public AjaxResult edit(@RequestBody SysUserExpand sysUserExpand) {
        return toAjax(sysUserExpandService.updateSysUserExpand(sysUserExpand));
    }

    /**
     * 删除用户登录限制
     */
    @ApiOperation("删除用户登录限制")
    @PreAuthorize("@ss.hasPermi('system:expand:remove')")
    @Log(title = "用户登录限制", businessType = BusinessType.DELETE)
    @DeleteMapping("/{userIds}")
    public AjaxResult remove(@PathVariable Long[] userIds) {
        return toAjax(sysUserExpandService.deleteSysUserExpandByUserIds(userIds));
    }
}
