package com.test;

import com.doc.common.utils.encrypt.Sm2Util;
import org.apache.commons.lang3.tuple.Pair;
import org.apache.pdfbox.pdmodel.PDDocument;
import org.apache.pdfbox.pdmodel.PDPage;
import org.apache.pdfbox.pdmodel.PDPageContentStream;
import org.apache.pdfbox.pdmodel.common.PDRectangle;
import org.apache.pdfbox.pdmodel.graphics.image.PDImageXObject;
import org.apache.pdfbox.rendering.ImageType;
import org.apache.pdfbox.rendering.PDFRenderer;

import javax.imageio.ImageIO;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

public class PdfUtil {
    public static void main(String[] args) {
        String path = "D:\\SYSTEM\\Desktop\\temp\\pdf";
        String source = path + File.separator + "test.pdf";
        Pair<Boolean, Object> pair = pdfToImage(source, path + "\\img1\\", "再测", "png");
        if (pair.getLeft()) {
            List<Object> fileList = (List<Object>) pair.getRight();
            fileList.forEach(o -> {
                System.err.println(o);
            });
        }

    }

    /**
     * 图片文件转PDF
     *
     * @param sources sm2加密后的绝对路径
     * @return pdf文件
     */
    public static File imageToPdf(List<String> sources) {
        //生成一页 PDF document
        try (PDDocument document = new PDDocument()) {
            for (String path : sources) {
                path = Sm2Util.decrypt(path);
                addPae(document, path);
            }
            // 4. 保存PDF
            File file = File.createTempFile("doc", ".pdf");
            document.save(file);
            return file;
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        }
    }

    /**
     * 添加图片
     *
     * @param document doc
     * @param path     路径
     * @throws IOException
     */
    private static void addPae(PDDocument document, String path) {
        try {
            // 这里是你生成PDF自适应图片大小，不设置会默认为A4
            PDImageXObject image = PDImageXObject.createFromFile(path, document);
            PDRectangle pageSize = new PDRectangle(image.getWidth(), image.getHeight());
            PDPage page = new PDPage(PDRectangle.A4);
            document.addPage(page);

            // 3.将 图片 添加进PDF document
            try (PDPageContentStream contentStream = new PDPageContentStream(document, page)) {
                // 这里是将你的图片填充入pdf页
                contentStream.drawImage(image, 0, 0);
            }
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    /**
     * @param source      原文件
     * @param desFilePath 生成图片的路径
     * @param desFileName 生成图片的名称（多页文档时会变成：名称+下划线+从1开始的数字）
     * @param imageType   图片类型
     * @return
     */
    public static Pair<Boolean, Object> pdfToImage(String source, String desFilePath, String desFileName, String imageType) {
        //通过给定的源路径名字符串创建一个File实例
        File file = new File(source);
        if (!file.exists()) {
            return Pair.of(false, "文件不存在，无法转化");
        }
        //目录不存在则创建目录
        File destination = new File(desFilePath);
        if (!destination.exists()) {
            boolean flag = destination.mkdirs();
            System.out.println("创建文件夹结果：" + flag);
        }
        try (PDDocument doc = PDDocument.load(file)) {
            //加载PDF文件
            PDFRenderer renderer = new PDFRenderer(doc);
            //获取PDF文档的页数
            int pageCount = doc.getNumberOfPages();
            System.out.println("文档一共" + pageCount + "页");
            List<Object> fileList = new ArrayList<>();
            for (int i = 0; i < pageCount; i++) {
                //只有一页的时候文件名为传入的文件名，大于一页的文件名为：文件名_自增加数字(从1开始)
                String realFileName = pageCount > 1 ? desFileName + "_" + (i + 1) : desFileName;
                //每一页通过分辨率和颜色值进行转化
                BufferedImage bufferedImage = renderer.renderImageWithDPI(i, 96 * 2, ImageType.RGB);
                String filePath = desFilePath + File.separator + realFileName + "." + imageType;
                //写入文件
                ImageIO.write(bufferedImage, imageType, new File(filePath));
                //文件名存入list
                fileList.add(filePath);
            }
            return Pair.of(true, fileList);
        } catch (IOException e) {
            e.printStackTrace();
            return Pair.of(false, "PDF转化图片异常");
        }
    }
}

