package com.doc.biz.controller;

import com.doc.biz.domain.DocInfo;
import com.doc.biz.domain.DocRecent;
import com.doc.biz.service.IDocInfoService;
import com.doc.biz.service.IDocRecentService;
import com.doc.biz.service.IMongoService;
import com.doc.biz.service.IOcrService;
import com.doc.common.core.controller.BaseController;
import com.doc.common.core.domain.AjaxResult;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;

/**
 * 文件上传
 *
 * @author wukai
 * @date 2023-08-15
 */
@Slf4j
@Api(tags = "通用接口")
@RestController
@RequestMapping("/api")
public class ApiController extends BaseController {

    /**
     * 文件上传实现类
     */
    @Resource
    private IMongoService mongoService;
    @Resource
    private IDocRecentService recentService;
    @Resource
    private IDocInfoService docInfoService;
    @Resource
    private IOcrService ocrService;

    /**
     * 文件预览
     *
     * @param docId docId
     * @return
     */
    @ApiOperation("文件预览")
    @GetMapping("/access/{docId}")
    public ResponseEntity<Object> access(@PathVariable(name = "docId") Long docId, @RequestParam Long uid) {
        DocInfo info = docInfoService.selectDocInfoByDocId(docId);
        //插入最近文件
        DocRecent recent = new DocRecent();
        recent.setIsFolder("N");
        recent.setOwner(uid);
        recent.setRelaId(info.getDocId());
        recentService.insertDocRecent(recent);
        return mongoService.download(info.getFileId(), false);
    }

    /**
     * 历史文件预览
     *
     * @param fileId fileId
     * @return
     */
    @ApiOperation("历史文件预览")
    @GetMapping("/history/{fileId}")
    public ResponseEntity<Object> access(@PathVariable(name = "fileId") String fileId) {
        return mongoService.download(fileId, false);
    }

    /**
     * 文字识别
     *
     * @param fileId fileId
     * @return ajax
     */
    @ApiOperation("文字识别-通过fileId")
    @GetMapping("/ocr/{fileId}")
    public AjaxResult ocr(@PathVariable(name = "fileId") String fileId) {
        try {
            return success(ocrService.recognition(fileId));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }


    /**
     * 文字识别
     *
     * @param file 文件
     * @return ajax
     */
    @ApiOperation("文字识别-上传图片")
    @PostMapping("/upload")
    public AjaxResult ocr(@RequestParam(value = "file") MultipartFile file) {
        try {
            return success(ocrService.recognition(file));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

}
