package com.doc.biz.controller;

import com.doc.biz.domain.DocFavoriteLabel;
import com.doc.biz.service.IDocFavoriteLabelService;
import com.doc.common.annotation.Log;
import com.doc.common.core.controller.BaseController;
import com.doc.common.core.domain.AjaxResult;
import com.doc.common.core.page.TableDataInfo;
import com.doc.common.enums.BusinessType;
import com.doc.common.utils.SecurityUtils;
import com.doc.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageHelper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 文件收藏标签Controller
 *
 * @author wukai
 * @date 2023-08-15
 */
@Api(tags = "文件收藏标签")
@RestController
@RequestMapping("/biz/label")
public class DocFavoriteLabelController extends BaseController {
    @Resource
    private IDocFavoriteLabelService docFavoriteLabelService;

    /**
     * 查询文件收藏标签列表
     */
    @ApiOperation("查询文件收藏标签列表")
    //@PreAuthorize("@ss.hasPermi('biz:label:list')")
    @GetMapping("/list")
    public TableDataInfo list(DocFavoriteLabel docFavoriteLabel) {
        startPage();
        List<DocFavoriteLabel> list = docFavoriteLabelService.selectDocFavoriteLabelList(docFavoriteLabel);
        return getDataTable(list);
    }

    /**
     * 导出文件收藏标签列表
     */
    @ApiOperation("导出文件收藏标签列表")
    //@PreAuthorize("@ss.hasPermi('biz:label:export')")
    @Log(title = "文件收藏标签", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DocFavoriteLabel docFavoriteLabel) {
        List<DocFavoriteLabel> list = docFavoriteLabelService.selectDocFavoriteLabelList(docFavoriteLabel);
        ExcelUtil<DocFavoriteLabel> util = new ExcelUtil<DocFavoriteLabel>(DocFavoriteLabel.class);
        util.exportExcel(response, list, "文件收藏标签数据");
    }

    /**
     * 获取文件收藏标签详细信息
     */
    @ApiOperation("获取文件收藏标签详细信息")
    //@PreAuthorize("@ss.hasPermi('biz:label:query')")
    @GetMapping(value = "/{labelId}")
    public AjaxResult getInfo(@PathVariable("labelId") Long labelId) {
        return success(docFavoriteLabelService.selectDocFavoriteLabelByLabelId(labelId));
    }

    /**
     * 新增文件收藏标签
     */
    @ApiOperation("新增文件收藏标签")
    //@PreAuthorize("@ss.hasPermi('biz:label:add')")
    @Log(title = "文件收藏标签", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DocFavoriteLabel docFavoriteLabel) {
        return toAjax(docFavoriteLabelService.insertDocFavoriteLabel(docFavoriteLabel));
    }

    /**
     * 标签排序
     */
    @ApiOperation("标签排序")
    @Log(title = "标签排序", businessType = BusinessType.UPDATE)
    @PostMapping(value = "order")
    public AjaxResult order(@RequestBody List<DocFavoriteLabel> labelList) {
        for (DocFavoriteLabel label : labelList) {
            label.setLabelName(null);
            docFavoriteLabelService.updateDocFavoriteLabel(label);
        }
        return success();
    }

    /**
     * 标签排序
     */
    @ApiOperation("标签列表")
    @Log(title = "标签列表", businessType = BusinessType.UPDATE)
    @GetMapping(value = "label-list")
    public List<DocFavoriteLabel> labelList() {
        PageHelper.startPage(1, 100, "order by order_num").setReasonable(true);
        DocFavoriteLabel docFavoriteLabel = new DocFavoriteLabel();
        docFavoriteLabel.setOwner(SecurityUtils.getUserId());
        List<DocFavoriteLabel> list = docFavoriteLabelService.selectDocFavoriteLabelList(docFavoriteLabel);
        return list;
    }

    /**
     * 修改文件收藏标签
     */
    @ApiOperation("修改文件收藏标签")
    //@PreAuthorize("@ss.hasPermi('biz:label:edit')")
    @Log(title = "文件收藏标签", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DocFavoriteLabel docFavoriteLabel) {
        return toAjax(docFavoriteLabelService.updateDocFavoriteLabel(docFavoriteLabel));
    }

    /**
     * 删除文件收藏标签
     */
    @ApiOperation("删除文件收藏标签")
    //@PreAuthorize("@ss.hasPermi('biz:label:remove')")
    @Log(title = "文件收藏标签", businessType = BusinessType.DELETE)
    @DeleteMapping("/{labelIds}")
    public AjaxResult remove(@PathVariable Long[] labelIds) {
        return toAjax(docFavoriteLabelService.deleteDocFavoriteLabelByLabelIds(labelIds));
    }
}
