package com.doc.biz.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.doc.common.annotation.Log;
import com.doc.common.core.controller.BaseController;
import com.doc.common.core.domain.AjaxResult;
import com.doc.common.enums.BusinessType;
import com.doc.biz.domain.DocIndex;
import com.doc.biz.service.IDocIndexService;
import com.doc.common.utils.poi.ExcelUtil;
import com.doc.common.core.page.TableDataInfo;

/**
 * 文件ES索引;存储解析错误和需要延迟解析的Controller
 * 
 * @author wukai
 * @date 2023-12-14
 */
@Api(tags="文件ES索引;存储解析错误和需要延迟解析的")
@RestController
@RequestMapping("/biz/index")
public class DocIndexController extends BaseController
{
    @Resource
    private IDocIndexService docIndexService;

    /**
     * 查询文件ES索引;存储解析错误和需要延迟解析的列表
     */
    @ApiOperation("查询文件ES索引;存储解析错误和需要延迟解析的列表")
    @PreAuthorize("@ss.hasPermi('biz:index:list')")
    @GetMapping("/list")
    public TableDataInfo list(DocIndex docIndex)
    {
        startPage();
        List<DocIndex> list = docIndexService.selectDocIndexList(docIndex);
        return getDataTable(list);
    }

    /**
     * 导出文件ES索引;存储解析错误和需要延迟解析的列表
     */
    @ApiOperation("导出文件ES索引;存储解析错误和需要延迟解析的列表")
    @PreAuthorize("@ss.hasPermi('biz:index:export')")
    @Log(title = "文件ES索引;存储解析错误和需要延迟解析的", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DocIndex docIndex)
    {
        List<DocIndex> list = docIndexService.selectDocIndexList(docIndex);
        ExcelUtil<DocIndex> util = new ExcelUtil<DocIndex>(DocIndex.class);
        util.exportExcel(response, list, "文件ES索引;存储解析错误和需要延迟解析的数据");
    }

    /**
     * 获取文件ES索引;存储解析错误和需要延迟解析的详细信息
     */
    @ApiOperation("获取文件ES索引;存储解析错误和需要延迟解析的详细信息")
    @PreAuthorize("@ss.hasPermi('biz:index:query')")
    @GetMapping(value = "/{docId}")
    public AjaxResult getInfo(@PathVariable("docId") Long docId)
    {
        return success(docIndexService.selectDocIndexByDocId(docId));
    }

    /**
     * 新增文件ES索引;存储解析错误和需要延迟解析的
     */
    @ApiOperation("新增文件ES索引;存储解析错误和需要延迟解析的")
    @PreAuthorize("@ss.hasPermi('biz:index:add')")
    @Log(title = "文件ES索引;存储解析错误和需要延迟解析的", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DocIndex docIndex)
    {
        return toAjax(docIndexService.insertDocIndex(docIndex));
    }

    /**
     * 修改文件ES索引;存储解析错误和需要延迟解析的
     */
    @ApiOperation("修改文件ES索引;存储解析错误和需要延迟解析的")
    @PreAuthorize("@ss.hasPermi('biz:index:edit')")
    @Log(title = "文件ES索引;存储解析错误和需要延迟解析的", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DocIndex docIndex)
    {
        return toAjax(docIndexService.updateDocIndex(docIndex));
    }

    /**
     * 删除文件ES索引;存储解析错误和需要延迟解析的
     */
    @ApiOperation("删除文件ES索引;存储解析错误和需要延迟解析的")
    @PreAuthorize("@ss.hasPermi('biz:index:remove')")
    @Log(title = "文件ES索引;存储解析错误和需要延迟解析的", businessType = BusinessType.DELETE)
	@DeleteMapping("/{docIds}")
    public AjaxResult remove(@PathVariable Long[] docIds)
    {
        return toAjax(docIndexService.deleteDocIndexByDocIds(docIds));
    }
}
