package com.doc.biz.controller;

import com.doc.biz.domain.DocInfo;
import com.doc.biz.domain.DocSpace;
import com.doc.biz.domain.EsDocInfo;
import com.doc.biz.service.IDocInfoService;
import com.doc.biz.service.IDocSpaceService;
import com.doc.biz.service.IEsDocInfoService;
import com.doc.common.config.EsConfig;
import com.doc.common.core.domain.AjaxResult;
import com.doc.common.enums.SpaceType;
import com.doc.common.utils.SecurityUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.data.elasticsearch.NoSuchIndexException;
import org.springframework.data.elasticsearch.core.SearchHit;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 * es查询控制器
 *
 * @author wukai
 */
@Api(tags = "全文搜索")
@RestController
@RequestMapping("/es")
public class ElasticSearchController {
    @Resource
    private IEsDocInfoService esDocInfoService;
    @Resource
    private IDocInfoService infoService;
    @Resource
    private EsConfig esConfig;
    @Resource
    private IDocSpaceService docSpaceService;


    /**
     * 模糊查询ik分词器分词的content字段
     *
     * @return
     */
    @GetMapping("/query")
    @ApiOperation("模糊查询")
    @ApiImplicitParams({@ApiImplicitParam(name = "type", value = "空间类型(1.公共空间 2.部门空间 3.个人空间", required = true), @ApiImplicitParam(name = "keyword", value = "搜索关键字", required = true), @ApiImplicitParam(name = "page", value = "当前页码", required = true), @ApiImplicitParam(name = "size", value = "每页条数", required = true)})
    public AjaxResult query(String type, String keyword, int page, int size) {
        //因为es查询是从第0页开始，所以页码要-1才行
        page = page - 1;
        DocSpace space = new DocSpace();
        space.setSpaceType(type);

        if (type.equals(SpaceType.DEPT.getValue())) {
            space.setOwner(SecurityUtils.getDeptId());
        } else if (type.equals(SpaceType.PERSONAL.getValue())) {
            space.setOwner(SecurityUtils.getUserId());
        }
        List<DocSpace> list = docSpaceService.selectDocSpaceList(space);
        if (list.size() > 0) {
            String indexName = "docs_" + list.get(0).getSpaceId();
            esConfig.setIndexName(indexName);
            try {

                List<SearchHit<EsDocInfo>> all = esDocInfoService.findByContent(keyword, PageRequest.of(page, size, Sort.by(Sort.Order.desc("id"))));
                List<SearchHit<EsDocInfo>> result = new ArrayList<>();
                if (all.size() > 0) {
                    for (SearchHit<EsDocInfo> re : all) {
                        EsDocInfo esDocInfo = re.getContent();
                        DocInfo docInfo = infoService.selectDocInfoByDocId(esDocInfo.getId());
                        if (docInfo != null) {
                            esDocInfo.setDocInfo(docInfo);
                            result.add(re);
                        }
                    }
                    return AjaxResult.success("查询成功", result);
                } else {
                    return AjaxResult.success("无结果");
                }
            } catch (NoSuchIndexException e) {
                return AjaxResult.success("无结果");
            }
        } else {
            return AjaxResult.success("无结果");
        }
    }
}
