package com.doc.biz.controller;

import com.alibaba.fastjson2.JSONObject;
import com.doc.biz.domain.DocInfo;
import com.doc.biz.domain.DocVersion;
import com.doc.biz.service.IDocInfoService;
import com.doc.biz.service.IDocVersionService;
import com.doc.biz.service.IMongoService;
import com.doc.biz.vo.DocumentVO;
import com.doc.common.core.domain.entity.SysUser;
import com.doc.common.enums.*;
import com.doc.common.utils.file.FileUtils;
import com.doc.system.domain.SysOperLog;
import com.doc.system.service.ISysOperLogService;
import com.doc.system.service.ISysUserService;
import lombok.extern.slf4j.Slf4j;
import org.apache.http.HttpEntity;
import org.apache.http.HttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.conn.ssl.NoopHostnameVerifier;
import org.apache.http.conn.ssl.SSLConnectionSocketFactory;
import org.apache.http.conn.ssl.TrustSelfSignedStrategy;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.ssl.SSLContexts;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.InputStream;
import java.io.PrintWriter;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.Date;
import java.util.Scanner;

/**
 * 分组成员Controller
 *
 * @author wukai
 * @date 2023-03-27
 */
@RestController
@RequestMapping("/only-office")
@Slf4j
public class OnlyOfficeController {
    @Resource
    private IDocInfoService docInfoService;
    @Resource
    private IMongoService mongoService;
    @Resource
    private IDocVersionService versionService;
    @Resource
    private ISysUserService userService;
    @Resource
    private ISysOperLogService operLogService;

    /**
     * only office修改回调
     *
     * @param id       文档ID
     * @param request  请求参数
     * @param response 响应参数
     */
    @RequestMapping("/callback/{id}")
    @ResponseBody
    public void save(@PathVariable("id") Long id, HttpServletRequest request, HttpServletResponse response) throws Exception {
        PrintWriter writer = null;
        String body = "";
        long start = System.currentTimeMillis();
        try (Scanner scanner = new Scanner(request.getInputStream());) {
            writer = response.getWriter();
            scanner.useDelimiter("\\A");
            body = scanner.hasNext() ? scanner.next() : "";
        } catch (Exception ex) {
            log.error("get request.getInputStream error:{}", ex.getMessage());
            writer.write("get request.getInputStream error:" + ex.getMessage());
            return;
        }

        if (body.isEmpty()) {
            log.error("ONLYOFFICE回调保存请求体为空");
            throw new Exception("ONLYOFFICE回调保存请求体为空");
        }

        JSONObject jsonObj = JSONObject.parseObject(body);
        int status = (Integer) jsonObj.get("status");
        /* 定义文档的状态。 可以有以下值：
         * 1 - 正在编辑文档，
         * 2 - 文档已准备好保存，
         * 3 - 发生文档保存错误，
         * 4 - 文档已关闭，没有任何更改，
         * 6 - 正在编辑文档，但保存了当前文档状态，
         * 7 - 强制保存文档时发生错误。*/

        int save = 2;
        int saveError = 3;
        int forceSave = 6;
        int saved = 0;

        /*这个key是 fileID,暂时不用的
         * String key = jsonObj.get("key").toString();*/

        if (status == save || status == saveError || status == forceSave) {
            //获取用户信息
            SysUser user = userService.selectUserById(jsonObj.getJSONArray("actions").getJSONObject(0).getLong("userid"));
            String downloadUri = (String) jsonObj.get("url");
            DocInfo info = docInfoService.selectDocInfoByDocId(id);

            try {
                MultipartFile multipartFile;
                String https = "https";
                if (downloadUri.contains(https)) {
                    SSLConnectionSocketFactory scsf = new SSLConnectionSocketFactory(SSLContexts.custom().loadTrustMaterial(null, new TrustSelfSignedStrategy()).build(),
                            NoopHostnameVerifier.INSTANCE);
                    CloseableHttpClient client = HttpClients.custom().setSSLSocketFactory(scsf).build();
                    HttpGet httpget = new HttpGet(downloadUri);
                    HttpResponse res = client.execute(httpget);
                    HttpEntity entity = res.getEntity();
                    try (InputStream is = entity.getContent()) {
                        multipartFile = FileUtils.getMultipartFile(is, info.getFileName());
                        process(info, user, multipartFile);
                    } catch (Exception e) {
                        throw e;
                    }
                } else {
                    URL url = new URL(downloadUri);
                    HttpURLConnection connection = (java.net.HttpURLConnection) url.openConnection();
                    multipartFile = FileUtils.getMultipartFile(connection.getInputStream(), info.getFileName());
                    process(info, user, multipartFile);
                    connection.disconnect();
                }

            } catch (Exception ex) {
                log.error("OnlyOffice异常消息：{}", ex.getMessage());
                saved = 1;
            }
        }

        String result = "{\"error\":" + saved + "}";
        //操作日志
        operLog(body, result, start);
        writer.write(result);
    }

    /**
     * 保存历史版本，处理新的文件信息
     *
     * @param info          文档信息
     * @param user          用户信息
     * @param multipartFile 多媒体文件
     */
    private void process(DocInfo info, SysUser user, MultipartFile multipartFile) {
        try {
            //保存版本信息
            DocVersion version = new DocVersion();
            version.setDocId(info.getDocId());
            version.setFileId(info.getFileId());
            version.setCreateBy(info.getCreateBy());
            version.setCreateTime(info.getCreateTime());
            versionService.insertDocVersion(version);

            //保存新的文件信息
            DocumentVO vo = mongoService.uploadFile(multipartFile);
            info.setFileId(vo.getFileId());
            info.setFileSize(vo.getFileSize());
            info.setCreateBy(user.getUserName());
            info.setCreateTime(new Date());
            info.setUpdateBy(user.getUserName());
            docInfoService.updateDocInfoByOnlyOffice(info);
        } catch (Exception e) {
            log.error("onlyoffice回调出错啦:{}", e.getMessage());
        }
    }

    /**
     * 插入操作日志
     *
     * @param body   请求参数
     * @param result 返回结果
     * @param start  开始处理时间
     */
    private void operLog(String body, String result, long start) {
        //设置操作日志
        SysOperLog log = new SysOperLog();
        // 设置action动作
        log.setBusinessType(BusinessType.UPDATE.ordinal());
        // 设置标题
        log.setTitle("onlyoffice回调");
        // 设置事件类型
        log.setEventType(EventType.SYSTEM.ordinal());
        // 设置事件级别
        log.setEventLevel(EventLevel.HIGH.ordinal());
        // 设置操作人类别
        log.setOperatorType(OperatorType.MANAGE.ordinal());
        log.setOperParam(body);
        log.setJsonResult(result);
        log.setStatus(BusinessStatus.SUCCESS.ordinal());
        // 设置消耗时间
        log.setCostTime(System.currentTimeMillis() - start);
        operLogService.insertOperlog(log);
        /*插入操作日志--end*/
    }
}
