package com.doc.biz.service;

import com.doc.biz.domain.DocDir;
import com.doc.biz.domain.DocSpace;

import java.util.List;
import java.util.Map;

/**
 * 文档目录管理Service接口
 *
 * @author wukai
 * @date 2023-08-15
 */
public interface IDocDirService {
    /**
     * 查询文档目录管理
     *
     * @param dirId 文档目录管理主键
     * @return 文档目录管理
     */
    public DocDir selectDocDirByDirId(Long dirId);

    /**
     * 查询目录是否有某个权限
     *
     * @param dirId     文档目录管理主键
     * @param roleCode 权限编码
     * @return 文档目录管理
     */
    Boolean hasRole(Long dirId, String roleCode);

    /**
     * 验证访问码
     *
     * @param dirId      文档目录管理主键
     * @param accessCode SM3加密之后的访问码
     * @return 文档目录管理
     */
    boolean matchesCode(Long dirId, String accessCode);

    /**
     * 查询文档目录管理列表
     *
     * @param docDir 文档目录管理
     * @return 文档目录管理集合
     */
    public List<DocDir> selectDocDirList(DocDir docDir);

    /**
     * 新增文档目录管理
     *
     * @param docDir 文档目录管理
     * @return 结果
     */
    public int insertDocDir(DocDir docDir);

    /**
     * 修改文档目录管理
     *
     * @param docDir 文档目录管理
     * @return 结果
     */
    public int updateDocDir(DocDir docDir);

    /**
     * 批量删除文档目录管理
     *
     * @param dirIds 需要删除的文档目录管理主键集合
     * @return 结果
     */
    public int deleteDocDirByDirIds(Long[] dirIds);

    /**
     * 删除文档目录管理信息
     *
     * @param dirId 文档目录管理主键
     * @return 结果
     */
    public int deleteDocDirByDirId(Long dirId);

    /**
     * 初始化顶层目录
     *
     * @param space 空间信息
     */
    void initTopDir(DocSpace space);

    /**
     * 查询当前用户下所有有权限的目录
     *
     * @param userId 用户ID
     * @param type   空间类型
     * @return 结果集
     */
    Map<String, Object> selectDirByUser(Long userId, String type);

    /**
     * 添加公共目录和部门目录权限控制
     *
     * @param docDir  目录
     * @param type 空间类型
     */
    void addRole(DocDir docDir, String type);
}
