package com.doc.biz.service;

import com.doc.biz.domain.DocFavorite;

import java.util.List;

/**
 * 文件收藏Service接口
 *
 * @author wukai
 * @date 2023-08-15
 */
public interface IDocFavoriteService {
    /**
     * 查询文件收藏
     *
     * @param favoriteId 文件收藏主键
     * @return 文件收藏
     */
    public DocFavorite selectDocFavoriteByFavoriteId(Long favoriteId);

    /**
     * 查询文件收藏列表
     *
     * @param docFavorite 文件收藏
     * @return 文件收藏集合
     */
    public List<DocFavorite> selectDocFavoriteList(DocFavorite docFavorite);

    /**
     * 新增文件收藏
     *
     * @param docFavorite 文件收藏
     * @return 结果
     */
    public int insertDocFavorite(DocFavorite docFavorite);

    /**
     * 修改文件收藏
     *
     * @param docFavorite 文件收藏
     * @return 结果
     */
    public int updateDocFavorite(DocFavorite docFavorite);

    /**
     * 批量删除文件收藏
     *
     * @param favoriteIds 需要删除的文件收藏主键集合
     * @return 结果
     */
    public int deleteDocFavoriteByFavoriteIds(Long[] favoriteIds);

    /**
     * 删除文件收藏信息
     *
     * @param favoriteId 文件收藏主键
     * @return 结果
     */
    public int deleteDocFavoriteByFavoriteId(Long favoriteId);

    /**
     * 删除收藏记录
     * @param isFolder 是否文件夹
     * @param realId 关联ID
     */
    void delete(String isFolder, Long realId);

    /**
     * 取消收藏
     * @param docFavorite 对象
     * @return
     */
    int cancel(DocFavorite docFavorite);
}
