package com.doc.biz.service;

import com.doc.biz.domain.DocInfo;
import com.doc.biz.vo.DocumentVO;

import java.util.List;

/**
 * 文件基本信息表Service接口
 *
 * @author wukai
 * @date 2023-08-15
 */
public interface IDocInfoService {
    /**
     * 查询文件基本信息表
     *
     * @param docId 文件基本信息表主键
     * @return 文件基本信息表
     */
    public DocInfo selectDocInfoByDocId(Long docId);

    /**
     * 查询文件基本信息表列表
     *
     * @param docInfo 文件基本信息表
     * @return 文件基本信息表集合
     */
    public List<DocInfo> selectDocInfoList(DocInfo docInfo);

    /**
     * 新增文件基本信息表
     *
     * @param docInfo 文件基本信息表
     * @return 结果
     */
    public int insertDocInfo(DocInfo docInfo);

    /**
     * 修改文件基本信息表
     *
     * @param docInfo 文件基本信息表
     * @return 结果
     */
    public int updateDocInfo(DocInfo docInfo);

    /**
     * 批量删除文件基本信息表
     *
     * @param docIds 需要删除的文件基本信息表主键集合
     * @return 结果
     */
    public int deleteDocInfoByDocIds(Long[] docIds);

    /**
     * 删除文件基本信息表信息
     *
     * @param docId 文件基本信息表主键
     * @return 结果
     */
    public int deleteDocInfoByDocId(Long docId);

    /**
     * 通过fileID查询文件基本信息
     *
     * @param fileId mongo文件ID
     * @return 对象
     */
    DocInfo selectDocInfoByFileId(String fileId);

    /**
     * only office更新文件内容
     *
     * @param info 文件信息
     */
    void updateDocInfoByOnlyOffice(DocInfo info);

    /**
     * 文件上传之后的操作
     *
     * @param vo      上传对象
     * @param spaceId 空间ID
     * @param dirId   目录ID
     * @return 对象
     */
    DocInfo upload(DocumentVO vo, Long spaceId, Long dirId);

    /**
     * 查询已失效的文件
     *
     * @return 失效文件列表
     */
    List<DocInfo> selectLoseList();
}
