package com.doc.biz.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.doc.biz.domain.DocActorUser;
import com.doc.biz.mapper.DocActorUserMapper;
import com.doc.biz.service.IDocActorUserService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 文档协作成员Service业务层处理
 *
 * @author wukai
 * @date 2023-09-18
 */
@Service
public class DocActorUserServiceImpl implements IDocActorUserService {
    @Resource
    private DocActorUserMapper docActorUserMapper;

    /**
     * 查询文档协作成员
     *
     * @param docId 文档协作成员主键
     * @return 文档协作成员
     */
    @Override
    public DocActorUser selectDocActorUserByDocId(Long docId) {
        return docActorUserMapper.selectDocActorUserByDocId(docId);
    }

    /**
     * 查询文档协作成员列表
     *
     * @param docActorUser 文档协作成员
     * @return 文档协作成员
     */
    @Override
    public List<DocActorUser> selectDocActorUserList(DocActorUser docActorUser) {
        return docActorUserMapper.selectDocActorUserList(docActorUser);
    }

    /**
     * 查询文档协作成员列表
     *
     * @param docId 文档ID
     * @return 文档协作成员集合
     */
    @Override
    public List<DocActorUser> selectDocActorUserListByDocId(Long docId) {
        DocActorUser au = new DocActorUser();
        au.setDocId(docId);
        return docActorUserMapper.selectDocActorUserList(au);
    }

    /**
     * 新增文档协作成员
     *
     * @param docActorUser 文档协作成员
     * @return 结果
     */
    @Override
    public int insertDocActorUser(DocActorUser docActorUser) {
        return docActorUserMapper.insertDocActorUser(docActorUser);
    }

    /**
     * 修改文档协作成员
     *
     * @param docActorUser 文档协作成员
     * @return 结果
     */
    @Override
    public int updateDocActorUser(DocActorUser docActorUser) {
        return docActorUserMapper.updateDocActorUser(docActorUser);
    }

    /**
     * 批量删除文档协作成员
     *
     * @param docIds 需要删除的文档协作成员主键
     * @return 结果
     */
    @Override
    public int deleteDocActorUserByDocIds(Long[] docIds) {
        return docActorUserMapper.deleteDocActorUserByDocIds(docIds);
    }

    /**
     * 删除文档协作成员信息
     *
     * @param docId 文档协作成员主键
     * @return 结果
     */
    @Override
    public int deleteDocActorUserByDocId(Long docId) {
        return docActorUserMapper.deleteDocActorUserByDocId(docId);
    }

    /**
     * 删除对象
     *
     * @param au 对象
     */
    @Override
    public void delete(DocActorUser au) {
        QueryWrapper<DocActorUser> queryWrapper = new QueryWrapper<>(au);
//        queryWrapper.eq("doc_id", au.getDocId());
//        queryWrapper.eq("user_id", au.getUserId());
        docActorUserMapper.delete(queryWrapper);
    }
}
