package com.doc.biz.service.impl;

import com.alibaba.fastjson2.JSONObject;
import com.doc.biz.domain.DocDirLevel;
import com.doc.biz.mapper.DocDirLevelMapper;
import com.doc.biz.service.IDocDirLevelService;
import com.doc.biz.vo.LevelVO;
import com.doc.common.utils.DateUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 文档目录加密级别Service业务层处理
 *
 * @author wukai
 * @date 2023-10-19
 */
@Service
public class DocDirLevelServiceImpl implements IDocDirLevelService {
    @Resource
    private DocDirLevelMapper docDirLevelMapper;

    /**
     * 查询文档目录加密级别
     *
     * @param levelId 文档目录加密级别主键
     * @return 文档目录加密级别
     */
    @Override
    public DocDirLevel selectDocDirLevelByLevelId(Long levelId) {
        return docDirLevelMapper.selectDocDirLevelByLevelId(levelId);
    }

    /**
     * 查询文档目录加密级别
     *
     * @param levelCode 文档目录加密级别主键
     * @return 文档目录加密级别
     */
    @Override
    public DocDirLevel selectDocDirLevelByLevelCode(String levelCode) {
        DocDirLevel docDirLevel = docDirLevelMapper.selectDocDirLevelByLevelCode(levelCode);
        process(docDirLevel);
        return docDirLevel;
    }

    private void process(DocDirLevel l) {
        JSONObject obj = JSONObject.parse(l.getLevelRoles());
        if (obj != null && !obj.isEmpty()) {
            l.setRoles(obj.toJavaObject(LevelVO.class));
        } else {
            l.setRoles(new LevelVO());
        }
    }

    /**
     * 查询文档目录加密级别列表
     *
     * @param docDirLevel 文档目录加密级别
     * @return 文档目录加密级别
     */
    @Override
    public List<DocDirLevel> selectDocDirLevelList(DocDirLevel docDirLevel) {
        List<DocDirLevel> list = docDirLevelMapper.selectDocDirLevelList(docDirLevel);
        list.forEach(l -> {
            process(l);
        });
        return list;
    }

    /**
     * 新增文档目录加密级别
     *
     * @param docDirLevel 文档目录加密级别
     * @return 结果
     */
    @Override
    public int insertDocDirLevel(DocDirLevel docDirLevel) {
        docDirLevel.setCreateTime(DateUtils.getNowDate());
        return docDirLevelMapper.insertDocDirLevel(docDirLevel);
    }

    /**
     * 修改文档目录加密级别
     *
     * @param docDirLevel 文档目录加密级别
     * @return 结果
     */
    @Override
    public int updateDocDirLevel(DocDirLevel docDirLevel) {
        docDirLevel.setUpdateTime(DateUtils.getNowDate());
        return docDirLevelMapper.updateDocDirLevel(docDirLevel);
    }

    /**
     * 修改文档目录加密级别
     *
     * @param docDirLevel 文档目录加密级别
     * @return 结果
     */
    @Override
    public int updateDocDirLevel(List<DocDirLevel> docDirLevel) {
        try {
            docDirLevel.forEach(l -> {
                l.setUpdateTime(DateUtils.getNowDate());
                JSONObject obj = JSONObject.from(l.getRoles());
                l.setLevelRoles(obj.toJSONString());
                docDirLevelMapper.updateDocDirLevel(l);
            });
        } catch (Exception e) {
            return 0;
        }
        return 1;
    }

    /**
     * 批量删除文档目录加密级别
     *
     * @param levelIds 需要删除的文档目录加密级别主键
     * @return 结果
     */
    @Override
    public int deleteDocDirLevelByLevelIds(Long[] levelIds) {
        return docDirLevelMapper.deleteDocDirLevelByLevelIds(levelIds);
    }

    /**
     * 删除文档目录加密级别信息
     *
     * @param levelId 文档目录加密级别主键
     * @return 结果
     */
    @Override
    public int deleteDocDirLevelByLevelId(Long levelId) {
        return docDirLevelMapper.deleteDocDirLevelByLevelId(levelId);
    }
}
