package com.doc.biz.service.impl;

import cn.hutool.http.HttpUtil;
import com.doc.biz.service.IMongoService;
import com.doc.biz.service.IOcrService;
import com.doc.biz.vo.DocumentVO;
import com.doc.system.service.ISysConfigService;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.io.File;
import java.io.IOException;
import java.nio.file.Files;
import java.util.HashMap;

/**
 * ElasticSearch 索引接口
 *
 * @author wukai
 * @date 2023-08-15
 */
@Service
public class OcrServiceImpl implements IOcrService {
    @Resource
    private ISysConfigService configService;
    @Resource
    private IMongoService mongoService;

    /**
     * 调用python接口获取结果
     *
     * @param fileId 文件ID
     * @return 识别结果
     */
    @Override
    public String recognition(String fileId) throws Exception {
        DocumentVO vo = mongoService.downloadFile(fileId);
        File upFile = File.createTempFile(vo.getFileName(), vo.getSuffix() + ".");
        Files.write(upFile.toPath(), vo.getData());
        return callPythonOcrApi(upFile);
    }

    /**
     * 调用python接口获取结果
     *
     * @param file 文件
     * @return 识别结果
     */
    @Override
    public String recognition(MultipartFile file) throws Exception {
        //选择用缓冲区来实现这个转换即使用java 创建的临时文件 使用 MultipartFile.transferto()方法 。
        String originalFilename = file.getOriginalFilename();
        String[] filename = originalFilename.split("\\.");
        File upFile = File.createTempFile(filename[0], filename[1] + ".");
        file.transferTo(upFile);
        return callPythonOcrApi(upFile);
    }

    /**
     * 调用python接口获取结果
     *
     * @param file 文件
     * @return 识别结果
     */
    private String callPythonOcrApi(File file) {
        HashMap<String, Object> map = new HashMap<>(3);
        map.put("file", file);
        String uri = configService.selectConfigByKey("api.ocr.uri");
        String result = HttpUtil.post(uri, map);
        try {
            Files.delete(file.toPath());
        } catch (IOException ignored) {
        }
        return result;
    }
}
