package com.doc.common.utils.file;

import com.doc.common.utils.DateUtils;
import com.doc.common.utils.encrypt.Sm2Util;
import org.apache.pdfbox.pdmodel.PDDocument;
import org.apache.pdfbox.pdmodel.PDPage;
import org.apache.pdfbox.pdmodel.PDPageContentStream;
import org.apache.pdfbox.pdmodel.common.PDRectangle;
import org.apache.pdfbox.pdmodel.graphics.image.PDImageXObject;
import org.apache.pdfbox.rendering.ImageType;
import org.apache.pdfbox.rendering.PDFRenderer;

import javax.imageio.ImageIO;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.ArrayList;
import java.util.List;

/**
 * pdf与图片互转工具类
 *
 * @author wukai
 */
public class PdfUtils {
    public static void main(String[] args) {
//        String path = "D:\\SYSTEM\\Desktop\\temp\\pdf";
//        String source = path + File.separator + "test.pdf";
//        pdfToImage(source, path + "\\img1", "\\测试一哈哈儿", "png");
        System.err.println(System.getProperty("java.io.tmpdir"));
    }

    /**
     * 图片文件转PDF
     *
     * @param sources sm2加密后的绝对路径
     * @return pdf文件
     */
    public static File imageToPdf(List<String> sources) {
        //1.生成一页 PDF document
        try (PDDocument document = new PDDocument()) {
            for (String path : sources) {
                path = Sm2Util.decrypt(path);
                File f = new File(path);
                if (!f.exists()) {
                    continue;
                }
                // 2.生成PDF默认A4大小
                PDPage page = new PDPage(PDRectangle.A4);
                document.addPage(page);
                // 3.将 图片 添加进PDF document
                try (PDPageContentStream contentStream = new PDPageContentStream(document, page)) {
                    PDImageXObject image = PDImageXObject.createFromFile(path, document);
                    float pageWidth = PDRectangle.A4.getWidth();
                    float pageHeight = PDRectangle.A4.getHeight();
                    float imageWidth = image.getWidth();
                    float imageHeight = image.getHeight();
                    float scale = Math.min(pageWidth / imageWidth, pageHeight / imageHeight);
                    float scaledWidth = imageWidth * scale;
                    float scaledHeight = imageHeight * scale;
                    float x = (pageWidth - scaledWidth) / 2;
                    float y = (pageHeight - scaledHeight) / 2;
                    // 将图片填充入pdf页
                    contentStream.drawImage(image, x, y, scaledWidth, scaledHeight);
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
            if (document.getPages().getCount() > 0) {
                // 4. 保存PDF
                File file = File.createTempFile("doc", ".pdf");
                document.save(file);
                for (String path : sources) {
                    //合并之后删除源文件
                    path = Sm2Util.decrypt(path);
                    FileUtils.deleteFile(path);
                }
                return file;
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }

    /**
     * @param data 源文件二进制
     * @return pair
     */
    public static List<File> pdfToImage(byte[] data) {
        //目录不存在则创建目录
        String tmpPath = System.getProperty("java.io.tmpdir") + File.separator + DateUtils.dateTimeNow();
        String tmpName = "tmp";
        String imageType = "png";
        List<File> result = new ArrayList<>();
        try {
            Files.createDirectory(Paths.get(tmpPath));
        } catch (IOException ignored) {
        }

        try (PDDocument doc = PDDocument.load(data)) {
            //加载PDF文件
            PDFRenderer renderer = new PDFRenderer(doc);
            //获取PDF文档的页数
            int pageCount = doc.getNumberOfPages();
            for (int i = 0; i < pageCount; i++) {
                //只有一页的时候文件名为传入的文件名，大于一页的文件名为：文件名_自增加数字(从101开始)
                String realFileName = pageCount > 1 ? tmpName + "_" + (i + 101) : tmpName;
                //每一页通过分辨率和颜色值进行转化
                BufferedImage bufferedImage = renderer.renderImageWithDPI(i, 96 * 2, ImageType.RGB);
                String filePath = tmpPath + File.separator + realFileName + "." + imageType;
                File f = new File(filePath);
                //写入文件
                ImageIO.write(bufferedImage, imageType, f);
                //文件名存入list
                result.add(f);
            }
        } catch (IOException e) {
            e.printStackTrace();
        }

        return result;
    }
}

