package com.doc.system.service.impl;

import com.doc.system.domain.SysAlarmSms;
import com.doc.system.mapper.SysAlarmSmsMapper;
import com.doc.system.service.ISysAlarmSmsService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

/**
 * 系统告警短信发送Service业务层处理
 *
 * @author wukai
 * @date 2023-12-12
 */
@Service
public class SysAlarmSmsServiceImpl implements ISysAlarmSmsService {
    @Resource
    private SysAlarmSmsMapper sysAlarmSmsMapper;

    /**
     * 查询系统告警短信发送
     *
     * @param alarmId 系统告警短信发送主键
     * @return 系统告警短信发送
     */
    @Override
    public SysAlarmSms selectSysAlarmSmsByAlarmId(Long alarmId) {
        return sysAlarmSmsMapper.selectSysAlarmSmsByAlarmId(alarmId);
    }

    /**
     * 查询系统告警短信发送列表
     *
     * @param sysAlarmSms 系统告警短信发送
     * @return 系统告警短信发送
     */
    @Override
    public List<SysAlarmSms> selectSysAlarmSmsList(SysAlarmSms sysAlarmSms) {
        return sysAlarmSmsMapper.selectSysAlarmSmsList(sysAlarmSms);
    }

    /**
     * 新增系统告警短信发送
     *
     * @param sysAlarmSms 系统告警短信发送
     * @return 结果
     */
    @Override
    public int insertSysAlarmSms(SysAlarmSms sysAlarmSms) {
        return sysAlarmSmsMapper.insertSysAlarmSms(sysAlarmSms);
    }

    /**
     * 修改系统告警短信发送
     *
     * @param sysAlarmSms 系统告警短信发送
     * @return 结果
     */
    @Override
    public int updateSysAlarmSms(SysAlarmSms sysAlarmSms) {
        return sysAlarmSmsMapper.updateSysAlarmSms(sysAlarmSms);
    }

    /**
     * 批量删除系统告警短信发送
     *
     * @param alarmIds 需要删除的系统告警短信发送主键
     * @return 结果
     */
    @Override
    public int deleteSysAlarmSmsByAlarmIds(Long[] alarmIds) {
        return sysAlarmSmsMapper.deleteSysAlarmSmsByAlarmIds(alarmIds);
    }

    /**
     * 删除系统告警短信发送信息
     *
     * @param alarmId 系统告警短信发送主键
     * @return 结果
     */
    @Override
    public int deleteSysAlarmSmsByAlarmId(Long alarmId) {
        return sysAlarmSmsMapper.deleteSysAlarmSmsByAlarmId(alarmId);
    }

    /**
     * 查询是否已经发送
     *
     * @param type 类型
     * @param key  关键字
     * @return
     */
    @Override
    public boolean isSend(int type, String key) {
        SysAlarmSms obj = new SysAlarmSms();
        obj.setAlarmType((long) type);
        obj.setAlartKey(key);
        obj.setSendTime(new Date());
        List list = sysAlarmSmsMapper.selectSysAlarmSmsList(obj);
        return list.size() > 0;
    }
}
