package com.doc.system.service.impl;

import com.doc.system.domain.SysOperLog;
import com.doc.system.domain.vo.LogCalcVO;
import com.doc.system.mapper.SysOperLogMapper;
import com.doc.system.service.ISysOperLogService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 操作日志 服务层处理
 *
 * @author ruoyi
 */
@Service
public class SysOperLogServiceImpl implements ISysOperLogService {
    @Resource
    private SysOperLogMapper operLogMapper;

    /**
     * 新增操作日志
     *
     * @param operLog 操作日志对象
     */
    @Override
    public void insertOperlog(SysOperLog operLog) {
        operLogMapper.insertOperlog(operLog);
    }

    /**
     * 查询系统操作日志集合
     *
     * @param operLog 操作日志对象
     * @return 操作日志集合
     */
    @Override
    public List<SysOperLog> selectOperLogList(SysOperLog operLog) {
        return operLogMapper.selectOperLogList(operLog);
    }

    /**
     * 批量删除系统操作日志
     *
     * @param operIds 需要删除的操作日志ID
     * @return 结果
     */
    @Override
    public int deleteOperLogByIds(Long[] operIds) {
        return operLogMapper.deleteOperLogByIds(operIds);
    }

    /**
     * 查询操作日志详细
     *
     * @param operId 操作ID
     * @return 操作日志对象
     */
    @Override
    public SysOperLog selectOperLogById(Long operId) {
        return operLogMapper.selectOperLogById(operId);
    }

    /**
     * 清空操作日志
     */
    @Override
    public void cleanOperLog() {
        operLogMapper.cleanOperLog();
    }

    /**
     * 查询统计数据
     *
     * @param operLog input
     * @return 结果集
     */
    @Override
    public List<LogCalcVO> selectOperLogCalc(SysOperLog operLog) {
        return operLogMapper.selectOperLogCalc(operLog);
    }


    /**
     * 查询按类型统计数据
     *
     * @param operLog input
     * @return 结果集
     */
    @Override
    public List<Map<String, Object>> selectTypeCalc(SysOperLog operLog) {
        return operLogMapper.selectTypeCalc(operLog);
    }

    /**
     * 查询按时间统计数据
     *
     * @param operLog input
     * @return 结果集
     */
    @Override
    public List<Map<String, Object>> selectTimeCalc(SysOperLog operLog) {
        return operLogMapper.selectTimeCalc(operLog);
    }
}
